slepc-3.18.0 2022-10-01
Report Typos and Errors

# EPSEVSLGetSlices

Gets the number of slices in which the interval must be subdivided.

### Synopsis

    #include "slepceps.h"
    PetscErrorCode EPSEVSLGetSlices(EPS eps,PetscInt *nslices)

Not Collective

### Input Parameter

| eps | - the eigensolver context

### Output Parameter

| nslices | - the number of slices

### See Also

EPSEVSLSetSlices()

### Level

intermediate

### Location

src/eps/impls/external/evsl/evsl.c
Index of all EPS routines
Table of Contents for all manual pages
Index of all manual pages